# dcat-ap-plus

This metadata schema is an Extension of the DCAT Application Profile
  for Providing Links to Use-case Specific Context. It allows to provide additional
  metadata regarding: which kind(s) of entity(s) or activity(s) were evaluated (the
  dcat:Dataset is about), which kind of activity generated the dcat:Dataset, which
  kind of instruments were used in the dataset generating activity, in which surrounding
  (e.g. a laboratory) and according to which plan the dataset generating activity
  took place, as well as regarding which kind(s) of qualitative and quantitative characteristic
  were attributed to the evaluated entity or evaluated activity and to the used instruments.

- Auto-generated [schema documentation](elements/overview.md)
